/*
 * Licensed Materials - Property of IBM
 *
 * com.ibm.etools.c
 *
 *  Copyright IBM Corporation 2004. All Rights Reserved. 
 *
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.etools.c.importer.AST;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.cdt.core.parser.IProblem;
import org.eclipse.cdt.core.parser.ast.IASTCompilationUnit;
import org.eclipse.cdt.core.parser.ast.IASTInclusion;

/**
 * This class extends the QuickParseCallback with some attributes needed by the
 * C-Importer
 * 
 * @author Bernhard Jakob, IBM
 */
//public class CParseCallback extends NullSourceElementRequestor {
public class CParseCallback extends WBICallback {

    public static final String copyright = "Licensed Material - Property of IBM\n com.ibm.etools.c\n(C) Copyright IBM Corp. 2004 - All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp."; //$NON-NLS-1$

    // file name of C source file to be imported
    private String fileName = null;

    private IASTCompilationUnit cu;

    private List inclusions = new ArrayList(1);

    private List problems = new ArrayList(1);

    /**
     * 
     * constructor
     *  
     */
    public CParseCallback() {
        super();
    }

    /**
     * 
     * getter method
     * 
     * @return String file name of C source to be imported
     *  
     */
    public String getFileName() {
        return fileName;
    }

    /**
     * 
     * setter method
     * 
     * @param String
     *            fileName of C source to be imported
     */
    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    /**
     *  
     */
    public void exitCompilationUnit(IASTCompilationUnit compUnit) {
        cu = compUnit;
    }

    /**
     * 
     * @return
     */
    public IASTCompilationUnit getCompilationUnit() {
        return cu;
    }

    /**
     * 
     * @return
     */
    public Iterator getInclusions() {
        return inclusions.iterator();
    }

    /**
     *  
     */
    public void enterInclusion(IASTInclusion inclusion) {
        inclusions.add(inclusion);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.cdt.core.parser.ISourceElementRequestor#acceptField(org.eclipse.cdt.core.parser.ast.IASTField)
     */

    public boolean acceptProblem(IProblem problem) {
        boolean problemAccepted = true;

        problemAccepted = super.acceptProblem(problem);

        if (problemAccepted) {
            problems.add(problem);
        }

        return problemAccepted;
    }

    /**
     * 
     * @return
     */
    public Iterator getProblems() {
        return problems.iterator();
    }
}